Adding options to make embedding of frameworks (i.e.: iOS 8 custom frameworks) as well as linking (i.e.: skipping it for header-only frameworks) optional.
diff --git a/test/addFramework.js b/test/addFramework.js
index 6b36f4b..60b1b81 100644
--- a/test/addFramework.js
+++ b/test/addFramework.js
@@ -128,7 +128,7 @@
         test.equal(buildFileEntry.fileRef, newFile.fileRef);
         test.equal(buildFileEntry.fileRef_comment, 'libsqlite3.dylib');
         test.deepEqual(buildFileEntry.settings, { ATTRIBUTES: [ 'Weak' ] });
-        
+
         test.done();
     },
     'should add to the Frameworks PBXGroup': function (test) {
@@ -155,6 +155,13 @@
         test.equal(frameworks.files.length, 16);
         test.done();
     },
+    'should not add to the PBXFrameworksBuildPhase': function (test) {
+        var newFile = proj.addFramework('Private.framework', {link: false}),
+            frameworks = proj.pbxFrameworksBuildPhaseObj();
+
+        test.equal(frameworks.files.length, 15);
+        test.done();
+    },
     'should have the right values for the Sources entry': function (test) {
         var newFile = proj.addFramework('libsqlite3.dylib'),
             frameworks = proj.pbxFrameworksBuildPhaseObj(),
@@ -188,12 +195,26 @@
         // should add path to framework search path
         var frameworkPaths = frameworkSearchPaths(proj);
             expectedPath = '"\\"/path/to\\""';
-        
+
         for (i = 0; i < frameworkPaths.length; i++) {
             var current = frameworkPaths[i];
             test.ok(current.indexOf('"$(inherited)"') >= 0);
             test.ok(current.indexOf(expectedPath) >= 0);
         }
         test.done();
-    }
+    },
+    'should add to the Embed Frameworks PBXCopyFilesBuildPhase': function (test) {
+        var newFile = proj.addFramework('/path/to/SomeEmbeddableCustom.framework', {customFramework: true, embed: true}),
+            frameworks = proj.pbxEmbedFrameworksBuildPhaseObj();
+
+        test.equal(frameworks.files.length, 1);
+        test.done();
+    },
+    'should not add to the Embed Frameworks PBXCopyFilesBuildPhase by default': function (test) {
+        var newFile = proj.addFramework('/path/to/Custom.framework', {customFramework: true}),
+            frameworks = proj.pbxEmbedFrameworksBuildPhaseObj();
+
+        test.equal(frameworks.files.length, 0);
+        test.done();
+    },
 }
diff --git a/test/fixtures/full-project.json b/test/fixtures/full-project.json
index ae4a5a7..09ec88e 100644
--- a/test/fixtures/full-project.json
+++ b/test/fixtures/full-project.json
@@ -1 +1,1252 @@
-{"project":{"archiveVersion":1,"classes":{},"objectVersion":45,"objects":{"PBXBuildFile":{"1D3623260D0F684500981E51":{"isa":"PBXBuildFile","fileRef":"1D3623250D0F684500981E51","fileRef_comment":"AppDelegate.m"},"1D3623260D0F684500981E51_comment":"AppDelegate.m in Sources","1D60589B0D05DD56006BFB54":{"isa":"PBXBuildFile","fileRef":"29B97316FDCFA39411CA2CEA","fileRef_comment":"main.m"},"1D60589B0D05DD56006BFB54_comment":"main.m in Sources","1D60589F0D05DD5A006BFB54":{"isa":"PBXBuildFile","fileRef":"1D30AB110D05D00D00671497","fileRef_comment":"Foundation.framework"},"1D60589F0D05DD5A006BFB54_comment":"Foundation.framework in Frameworks","1DF5F4E00D08C38300B7A737":{"isa":"PBXBuildFile","fileRef":"1DF5F4DF0D08C38300B7A737","fileRef_comment":"UIKit.framework","settings":{"ATTRIBUTES":["Weak"]}},"1DF5F4E00D08C38300B7A737_comment":"UIKit.framework in Frameworks","1F766FE113BBADB100FB74C0":{"isa":"PBXBuildFile","fileRef":"1F766FDC13BBADB100FB74C0","fileRef_comment":"Localizable.strings"},"1F766FE113BBADB100FB74C0_comment":"Localizable.strings in Resources","1F766FE213BBADB100FB74C0":{"isa":"PBXBuildFile","fileRef":"1F766FDF13BBADB100FB74C0","fileRef_comment":"Localizable.strings"},"1F766FE213BBADB100FB74C0_comment":"Localizable.strings in Resources","288765FD0DF74451002DB57D":{"isa":"PBXBuildFile","fileRef":"288765FC0DF74451002DB57D","fileRef_comment":"CoreGraphics.framework"},"288765FD0DF74451002DB57D_comment":"CoreGraphics.framework in Frameworks","301BF552109A68D80062928A":{"isa":"PBXBuildFile","fileRef":"301BF535109A57CC0062928A","fileRef_comment":"libPhoneGap.a"},"301BF552109A68D80062928A_comment":"libPhoneGap.a in Frameworks","301BF570109A69640062928A":{"isa":"PBXBuildFile","fileRef":"301BF56E109A69640062928A","fileRef_comment":"www"},"301BF570109A69640062928A_comment":"www in Resources","301BF5B5109A6A2B0062928A":{"isa":"PBXBuildFile","fileRef":"301BF5B4109A6A2B0062928A","fileRef_comment":"AddressBook.framework"},"301BF5B5109A6A2B0062928A_comment":"AddressBook.framework in Frameworks","301BF5B7109A6A2B0062928A":{"isa":"PBXBuildFile","fileRef":"301BF5B6109A6A2B0062928A","fileRef_comment":"AddressBookUI.framework"},"301BF5B7109A6A2B0062928A_comment":"AddressBookUI.framework in Frameworks","301BF5B9109A6A2B0062928A":{"isa":"PBXBuildFile","fileRef":"301BF5B8109A6A2B0062928A","fileRef_comment":"AudioToolbox.framework"},"301BF5B9109A6A2B0062928A_comment":"AudioToolbox.framework in Frameworks","301BF5BB109A6A2B0062928A":{"isa":"PBXBuildFile","fileRef":"301BF5BA109A6A2B0062928A","fileRef_comment":"AVFoundation.framework","settings":{"ATTRIBUTES":["Weak"]}},"301BF5BB109A6A2B0062928A_comment":"AVFoundation.framework in Frameworks","301BF5BD109A6A2B0062928A":{"isa":"PBXBuildFile","fileRef":"301BF5BC109A6A2B0062928A","fileRef_comment":"CFNetwork.framework"},"301BF5BD109A6A2B0062928A_comment":"CFNetwork.framework in Frameworks","301BF5BF109A6A2B0062928A":{"isa":"PBXBuildFile","fileRef":"301BF5BE109A6A2B0062928A","fileRef_comment":"CoreLocation.framework"},"301BF5BF109A6A2B0062928A_comment":"CoreLocation.framework in Frameworks","301BF5C1109A6A2B0062928A":{"isa":"PBXBuildFile","fileRef":"301BF5C0109A6A2B0062928A","fileRef_comment":"MediaPlayer.framework"},"301BF5C1109A6A2B0062928A_comment":"MediaPlayer.framework in Frameworks","301BF5C3109A6A2B0062928A":{"isa":"PBXBuildFile","fileRef":"301BF5C2109A6A2B0062928A","fileRef_comment":"QuartzCore.framework"},"301BF5C3109A6A2B0062928A_comment":"QuartzCore.framework in Frameworks","301BF5C5109A6A2B0062928A":{"isa":"PBXBuildFile","fileRef":"301BF5C4109A6A2B0062928A","fileRef_comment":"SystemConfiguration.framework"},"301BF5C5109A6A2B0062928A_comment":"SystemConfiguration.framework in Frameworks","3053AC6F109B7857006FCFE7":{"isa":"PBXBuildFile","fileRef":"3053AC6E109B7857006FCFE7","fileRef_comment":"VERSION"},"3053AC6F109B7857006FCFE7_comment":"VERSION in Resources","305D5FD1115AB8F900A74A75":{"isa":"PBXBuildFile","fileRef":"305D5FD0115AB8F900A74A75","fileRef_comment":"MobileCoreServices.framework"},"305D5FD1115AB8F900A74A75_comment":"MobileCoreServices.framework in Frameworks","3072F99713A8081B00425683":{"isa":"PBXBuildFile","fileRef":"3072F99613A8081B00425683","fileRef_comment":"Capture.bundle"},"3072F99713A8081B00425683_comment":"Capture.bundle in Resources","307D28A2123043360040C0FA":{"isa":"PBXBuildFile","fileRef":"307D28A1123043350040C0FA","fileRef_comment":"PhoneGapBuildSettings.xcconfig"},"307D28A2123043360040C0FA_comment":"PhoneGapBuildSettings.xcconfig in Resources","308D05371370CCF300D202BF":{"isa":"PBXBuildFile","fileRef":"308D052E1370CCF300D202BF","fileRef_comment":"icon-72.png"},"308D05371370CCF300D202BF_comment":"icon-72.png in Resources","308D05381370CCF300D202BF":{"isa":"PBXBuildFile","fileRef":"308D052F1370CCF300D202BF","fileRef_comment":"icon.png"},"308D05381370CCF300D202BF_comment":"icon.png in Resources","308D05391370CCF300D202BF":{"isa":"PBXBuildFile","fileRef":"308D05301370CCF300D202BF","fileRef_comment":"icon@2x.png"},"308D05391370CCF300D202BF_comment":"icon@2x.png in Resources","308D053C1370CCF300D202BF":{"isa":"PBXBuildFile","fileRef":"308D05341370CCF300D202BF","fileRef_comment":"Default.png"},"308D053C1370CCF300D202BF_comment":"Default.png in Resources","308D053D1370CCF300D202BF":{"isa":"PBXBuildFile","fileRef":"308D05351370CCF300D202BF","fileRef_comment":"Default@2x.png"},"308D053D1370CCF300D202BF_comment":"Default@2x.png in Resources","30E1352710E2C1420031B30D":{"isa":"PBXBuildFile","fileRef":"30E1352610E2C1420031B30D","fileRef_comment":"PhoneGap.plist"},"30E1352710E2C1420031B30D_comment":"PhoneGap.plist in Resources","30E5649213A7FCAF007403D8":{"isa":"PBXBuildFile","fileRef":"30E5649113A7FCAF007403D8","fileRef_comment":"CoreMedia.framework","settings":{"ATTRIBUTES":["Weak"]}},"30E5649213A7FCAF007403D8_comment":"CoreMedia.framework in Frameworks"},"PBXContainerItemProxy":{"301BF534109A57CC0062928A":{"isa":"PBXContainerItemProxy","containerPortal":"301BF52D109A57CC0062928A","containerPortal_comment":"PhoneGapLib.xcodeproj","proxyType":2,"remoteGlobalIDString":"D2AAC07E0554694100DB518D","remoteInfo":"PhoneGapLib"},"301BF534109A57CC0062928A_comment":"PBXContainerItemProxy","301BF550109A68C00062928A":{"isa":"PBXContainerItemProxy","containerPortal":"301BF52D109A57CC0062928A","containerPortal_comment":"PhoneGapLib.xcodeproj","proxyType":1,"remoteGlobalIDString":"D2AAC07D0554694100DB518D","remoteInfo":"PhoneGapLib"},"301BF550109A68C00062928A_comment":"PBXContainerItemProxy","30E47BC2136F595F00DBB853":{"isa":"PBXContainerItemProxy","containerPortal":"301BF52D109A57CC0062928A","containerPortal_comment":"PhoneGapLib.xcodeproj","proxyType":2,"remoteGlobalIDString":"303258D8136B2C9400982B63","remoteInfo":"PhoneGap"},"30E47BC2136F595F00DBB853_comment":"PBXContainerItemProxy"},"PBXFileReference":{"1D30AB110D05D00D00671497":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"Foundation.framework","path":"System/Library/Frameworks/Foundation.framework","sourceTree":"SDKROOT"},"1D30AB110D05D00D00671497_comment":"Foundation.framework","1D3623240D0F684500981E51":{"isa":"PBXFileReference","fileEncoding":4,"lastKnownFileType":"sourcecode.c.h","path":"AppDelegate.h","sourceTree":"\"<group>\""},"1D3623240D0F684500981E51_comment":"AppDelegate.h","1D3623250D0F684500981E51":{"isa":"PBXFileReference","fileEncoding":4,"lastKnownFileType":"sourcecode.c.objc","path":"AppDelegate.m","sourceTree":"\"<group>\""},"1D3623250D0F684500981E51_comment":"AppDelegate.m","1D6058910D05DD3D006BFB54":{"isa":"PBXFileReference","explicitFileType":"wrapper.application","includeInIndex":0,"path":"\"KitchenSinktablet.app\"","sourceTree":"BUILT_PRODUCTS_DIR"},"1D6058910D05DD3D006BFB54_comment":"KitchenSinktablet.app","1DF5F4DF0D08C38300B7A737":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"UIKit.framework","path":"System/Library/Frameworks/UIKit.framework","sourceTree":"SDKROOT"},"1DF5F4DF0D08C38300B7A737_comment":"UIKit.framework","1F766FDD13BBADB100FB74C0":{"isa":"PBXFileReference","lastKnownFileType":"text.plist.strings","name":"en","path":"Localizable.strings","sourceTree":"\"<group>\""},"1F766FDD13BBADB100FB74C0_comment":"en","1F766FE013BBADB100FB74C0":{"isa":"PBXFileReference","lastKnownFileType":"text.plist.strings","name":"es","path":"Localizable.strings","sourceTree":"\"<group>\""},"1F766FE013BBADB100FB74C0_comment":"es","288765FC0DF74451002DB57D":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"CoreGraphics.framework","path":"System/Library/Frameworks/CoreGraphics.framework","sourceTree":"SDKROOT"},"288765FC0DF74451002DB57D_comment":"CoreGraphics.framework","29B97316FDCFA39411CA2CEA":{"isa":"PBXFileReference","fileEncoding":4,"lastKnownFileType":"sourcecode.c.objc","path":"main.m","sourceTree":"\"<group>\""},"29B97316FDCFA39411CA2CEA_comment":"main.m","301BF52D109A57CC0062928A":{"isa":"PBXFileReference","lastKnownFileType":"\"wrapper.pb-project\"","path":"PhoneGapLib.xcodeproj","sourceTree":"PHONEGAPLIB"},"301BF52D109A57CC0062928A_comment":"PhoneGapLib.xcodeproj","301BF56E109A69640062928A":{"isa":"PBXFileReference","lastKnownFileType":"folder","path":"www","sourceTree":"SOURCE_ROOT"},"301BF56E109A69640062928A_comment":"www","301BF5B4109A6A2B0062928A":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"AddressBook.framework","path":"System/Library/Frameworks/AddressBook.framework","sourceTree":"SDKROOT"},"301BF5B4109A6A2B0062928A_comment":"AddressBook.framework","301BF5B6109A6A2B0062928A":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"AddressBookUI.framework","path":"System/Library/Frameworks/AddressBookUI.framework","sourceTree":"SDKROOT"},"301BF5B6109A6A2B0062928A_comment":"AddressBookUI.framework","301BF5B8109A6A2B0062928A":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"AudioToolbox.framework","path":"System/Library/Frameworks/AudioToolbox.framework","sourceTree":"SDKROOT"},"301BF5B8109A6A2B0062928A_comment":"AudioToolbox.framework","301BF5BA109A6A2B0062928A":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"AVFoundation.framework","path":"System/Library/Frameworks/AVFoundation.framework","sourceTree":"SDKROOT"},"301BF5BA109A6A2B0062928A_comment":"AVFoundation.framework","301BF5BC109A6A2B0062928A":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"CFNetwork.framework","path":"System/Library/Frameworks/CFNetwork.framework","sourceTree":"SDKROOT"},"301BF5BC109A6A2B0062928A_comment":"CFNetwork.framework","301BF5BE109A6A2B0062928A":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"CoreLocation.framework","path":"System/Library/Frameworks/CoreLocation.framework","sourceTree":"SDKROOT"},"301BF5BE109A6A2B0062928A_comment":"CoreLocation.framework","301BF5C0109A6A2B0062928A":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"MediaPlayer.framework","path":"System/Library/Frameworks/MediaPlayer.framework","sourceTree":"SDKROOT"},"301BF5C0109A6A2B0062928A_comment":"MediaPlayer.framework","301BF5C2109A6A2B0062928A":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"QuartzCore.framework","path":"System/Library/Frameworks/QuartzCore.framework","sourceTree":"SDKROOT"},"301BF5C2109A6A2B0062928A_comment":"QuartzCore.framework","301BF5C4109A6A2B0062928A":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"SystemConfiguration.framework","path":"System/Library/Frameworks/SystemConfiguration.framework","sourceTree":"SDKROOT"},"301BF5C4109A6A2B0062928A_comment":"SystemConfiguration.framework","3053AC6E109B7857006FCFE7":{"isa":"PBXFileReference","fileEncoding":4,"lastKnownFileType":"text","path":"VERSION","sourceTree":"PHONEGAPLIB"},"3053AC6E109B7857006FCFE7_comment":"VERSION","305D5FD0115AB8F900A74A75":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"MobileCoreServices.framework","path":"System/Library/Frameworks/MobileCoreServices.framework","sourceTree":"SDKROOT"},"305D5FD0115AB8F900A74A75_comment":"MobileCoreServices.framework","3072F99613A8081B00425683":{"isa":"PBXFileReference","lastKnownFileType":"\"wrapper.plug-in\"","name":"Capture.bundle","path":"Resources/Capture.bundle","sourceTree":"\"<group>\""},"3072F99613A8081B00425683_comment":"Capture.bundle","307D28A1123043350040C0FA":{"isa":"PBXFileReference","fileEncoding":4,"lastKnownFileType":"text.xcconfig","path":"PhoneGapBuildSettings.xcconfig","sourceTree":"\"<group>\""},"307D28A1123043350040C0FA_comment":"PhoneGapBuildSettings.xcconfig","308D052E1370CCF300D202BF":{"isa":"PBXFileReference","lastKnownFileType":"image.png","path":"\"icon-72.png\"","sourceTree":"\"<group>\""},"308D052E1370CCF300D202BF_comment":"icon-72.png","308D052F1370CCF300D202BF":{"isa":"PBXFileReference","lastKnownFileType":"image.png","path":"icon.png","sourceTree":"\"<group>\""},"308D052F1370CCF300D202BF_comment":"icon.png","308D05301370CCF300D202BF":{"isa":"PBXFileReference","lastKnownFileType":"image.png","path":"\"icon@2x.png\"","sourceTree":"\"<group>\""},"308D05301370CCF300D202BF_comment":"icon@2x.png","308D05341370CCF300D202BF":{"isa":"PBXFileReference","lastKnownFileType":"image.png","path":"Default.png","sourceTree":"\"<group>\""},"308D05341370CCF300D202BF_comment":"Default.png","308D05351370CCF300D202BF":{"isa":"PBXFileReference","lastKnownFileType":"image.png","path":"\"Default@2x.png\"","sourceTree":"\"<group>\""},"308D05351370CCF300D202BF_comment":"Default@2x.png","30E1352610E2C1420031B30D":{"isa":"PBXFileReference","fileEncoding":4,"lastKnownFileType":"text.plist.xml","path":"PhoneGap.plist","sourceTree":"\"<group>\""},"30E1352610E2C1420031B30D_comment":"PhoneGap.plist","30E5649113A7FCAF007403D8":{"isa":"PBXFileReference","lastKnownFileType":"wrapper.framework","name":"CoreMedia.framework","path":"System/Library/Frameworks/CoreMedia.framework","sourceTree":"SDKROOT"},"30E5649113A7FCAF007403D8_comment":"CoreMedia.framework","32CA4F630368D1EE00C91783":{"isa":"PBXFileReference","fileEncoding":4,"lastKnownFileType":"sourcecode.c.h","path":"\"KitchenSinktablet-Prefix.pch\"","sourceTree":"\"<group>\""},"32CA4F630368D1EE00C91783_comment":"KitchenSinktablet-Prefix.pch","8D1107310486CEB800E47090":{"isa":"PBXFileReference","fileEncoding":4,"lastKnownFileType":"text.plist.xml","path":"\"KitchenSinktablet-Info.plist\"","plistStructureDefinitionIdentifier":"\"com.apple.xcode.plist.structure-definition.iphone.info-plist\"","sourceTree":"\"<group>\""},"8D1107310486CEB800E47090_comment":"KitchenSinktablet-Info.plist"},"PBXFrameworksBuildPhase":{"1D60588F0D05DD3D006BFB54":{"isa":"PBXFrameworksBuildPhase","buildActionMask":2147483647,"files":[{"value":"301BF552109A68D80062928A","comment":"libPhoneGap.a in Frameworks"},{"value":"1D60589F0D05DD5A006BFB54","comment":"Foundation.framework in Frameworks"},{"value":"1DF5F4E00D08C38300B7A737","comment":"UIKit.framework in Frameworks"},{"value":"288765FD0DF74451002DB57D","comment":"CoreGraphics.framework in Frameworks"},{"value":"301BF5B5109A6A2B0062928A","comment":"AddressBook.framework in Frameworks"},{"value":"301BF5B7109A6A2B0062928A","comment":"AddressBookUI.framework in Frameworks"},{"value":"301BF5B9109A6A2B0062928A","comment":"AudioToolbox.framework in Frameworks"},{"value":"301BF5BB109A6A2B0062928A","comment":"AVFoundation.framework in Frameworks"},{"value":"301BF5BD109A6A2B0062928A","comment":"CFNetwork.framework in Frameworks"},{"value":"301BF5BF109A6A2B0062928A","comment":"CoreLocation.framework in Frameworks"},{"value":"301BF5C1109A6A2B0062928A","comment":"MediaPlayer.framework in Frameworks"},{"value":"301BF5C3109A6A2B0062928A","comment":"QuartzCore.framework in Frameworks"},{"value":"301BF5C5109A6A2B0062928A","comment":"SystemConfiguration.framework in Frameworks"},{"value":"305D5FD1115AB8F900A74A75","comment":"MobileCoreServices.framework in Frameworks"},{"value":"30E5649213A7FCAF007403D8","comment":"CoreMedia.framework in Frameworks"}],"runOnlyForDeploymentPostprocessing":0},"1D60588F0D05DD3D006BFB54_comment":"Frameworks"},"PBXGroup":{"080E96DDFE201D6D7F000001":{"isa":"PBXGroup","children":[{"value":"1D3623240D0F684500981E51","comment":"AppDelegate.h"},{"value":"1D3623250D0F684500981E51","comment":"AppDelegate.m"}],"path":"Classes","sourceTree":"SOURCE_ROOT"},"080E96DDFE201D6D7F000001_comment":"Classes","19C28FACFE9D520D11CA2CBB":{"isa":"PBXGroup","children":[{"value":"1D6058910D05DD3D006BFB54","comment":"KitchenSinktablet.app"}],"name":"Products","sourceTree":"\"<group>\""},"19C28FACFE9D520D11CA2CBB_comment":"Products","1F766FDB13BBADB100FB74C0":{"isa":"PBXGroup","children":[{"value":"1F766FDC13BBADB100FB74C0","comment":"Localizable.strings"}],"name":"en.lproj","path":"Resources/en.lproj","sourceTree":"\"<group>\""},"1F766FDB13BBADB100FB74C0_comment":"en.lproj","1F766FDE13BBADB100FB74C0":{"isa":"PBXGroup","children":[{"value":"1F766FDF13BBADB100FB74C0","comment":"Localizable.strings"}],"name":"es.lproj","path":"Resources/es.lproj","sourceTree":"\"<group>\""},"1F766FDE13BBADB100FB74C0_comment":"es.lproj","29B97314FDCFA39411CA2CEA":{"isa":"PBXGroup","children":[{"value":"301BF56E109A69640062928A","comment":"www"},{"value":"301BF52D109A57CC0062928A","comment":"PhoneGapLib.xcodeproj"},{"value":"080E96DDFE201D6D7F000001","comment":"Classes"},{"value":"307C750510C5A3420062BCA9","comment":"Plugins"},{"value":"29B97315FDCFA39411CA2CEA","comment":"Other Sources"},{"value":"29B97317FDCFA39411CA2CEA","comment":"Resources"},{"value":"29B97323FDCFA39411CA2CEA","comment":"Frameworks"},{"value":"19C28FACFE9D520D11CA2CBB","comment":"Products"}],"name":"CustomTemplate","sourceTree":"\"<group>\""},"29B97314FDCFA39411CA2CEA_comment":"CustomTemplate","29B97315FDCFA39411CA2CEA":{"isa":"PBXGroup","children":[{"value":"32CA4F630368D1EE00C91783","comment":"KitchenSinktablet-Prefix.pch"},{"value":"29B97316FDCFA39411CA2CEA","comment":"main.m"}],"name":"\"Other Sources\"","sourceTree":"\"<group>\""},"29B97315FDCFA39411CA2CEA_comment":"Other Sources","29B97317FDCFA39411CA2CEA":{"isa":"PBXGroup","children":[{"value":"1F766FDB13BBADB100FB74C0","comment":"en.lproj"},{"value":"1F766FDE13BBADB100FB74C0","comment":"es.lproj"},{"value":"3072F99613A8081B00425683","comment":"Capture.bundle"},{"value":"308D052D1370CCF300D202BF","comment":"icons"},{"value":"308D05311370CCF300D202BF","comment":"splash"},{"value":"30E1352610E2C1420031B30D","comment":"PhoneGap.plist"},{"value":"3053AC6E109B7857006FCFE7","comment":"VERSION"},{"value":"8D1107310486CEB800E47090","comment":"KitchenSinktablet-Info.plist"},{"value":"307D28A1123043350040C0FA","comment":"PhoneGapBuildSettings.xcconfig"}],"name":"Resources","sourceTree":"\"<group>\""},"29B97317FDCFA39411CA2CEA_comment":"Resources","29B97323FDCFA39411CA2CEA":{"isa":"PBXGroup","children":[{"value":"1DF5F4DF0D08C38300B7A737","comment":"UIKit.framework"},{"value":"1D30AB110D05D00D00671497","comment":"Foundation.framework"},{"value":"288765FC0DF74451002DB57D","comment":"CoreGraphics.framework"},{"value":"301BF5B4109A6A2B0062928A","comment":"AddressBook.framework"},{"value":"301BF5B6109A6A2B0062928A","comment":"AddressBookUI.framework"},{"value":"301BF5B8109A6A2B0062928A","comment":"AudioToolbox.framework"},{"value":"301BF5BA109A6A2B0062928A","comment":"AVFoundation.framework"},{"value":"301BF5BC109A6A2B0062928A","comment":"CFNetwork.framework"},{"value":"301BF5BE109A6A2B0062928A","comment":"CoreLocation.framework"},{"value":"301BF5C0109A6A2B0062928A","comment":"MediaPlayer.framework"},{"value":"301BF5C2109A6A2B0062928A","comment":"QuartzCore.framework"},{"value":"301BF5C4109A6A2B0062928A","comment":"SystemConfiguration.framework"},{"value":"305D5FD0115AB8F900A74A75","comment":"MobileCoreServices.framework"},{"value":"30E5649113A7FCAF007403D8","comment":"CoreMedia.framework"}],"name":"Frameworks","sourceTree":"\"<group>\""},"29B97323FDCFA39411CA2CEA_comment":"Frameworks","301BF52E109A57CC0062928A":{"isa":"PBXGroup","children":[{"value":"301BF535109A57CC0062928A","comment":"libPhoneGap.a"},{"value":"30E47BC3136F595F00DBB853","comment":"PhoneGap.framework"}],"name":"Products","sourceTree":"\"<group>\""},"301BF52E109A57CC0062928A_comment":"Products","307C750510C5A3420062BCA9":{"isa":"PBXGroup","children":[],"path":"Plugins","sourceTree":"SOURCE_ROOT"},"307C750510C5A3420062BCA9_comment":"Plugins","308D052D1370CCF300D202BF":{"isa":"PBXGroup","children":[{"value":"308D052E1370CCF300D202BF","comment":"icon-72.png"},{"value":"308D052F1370CCF300D202BF","comment":"icon.png"},{"value":"308D05301370CCF300D202BF","comment":"icon@2x.png"}],"name":"icons","path":"Resources/icons","sourceTree":"\"<group>\""},"308D052D1370CCF300D202BF_comment":"icons","308D05311370CCF300D202BF":{"isa":"PBXGroup","children":[{"value":"308D05341370CCF300D202BF","comment":"Default.png"},{"value":"308D05351370CCF300D202BF","comment":"Default@2x.png"}],"name":"splash","path":"Resources/splash","sourceTree":"\"<group>\""},"308D05311370CCF300D202BF_comment":"splash"},"PBXNativeTarget":{"1D6058900D05DD3D006BFB54":{"isa":"PBXNativeTarget","buildConfigurationList":"1D6058960D05DD3E006BFB54","buildConfigurationList_comment":"Build configuration list for PBXNativeTarget \"KitchenSinktablet\"","buildPhases":[{"value":"304B58A110DAC018002A0835","comment":"Touch www folder"},{"value":"1D60588D0D05DD3D006BFB54","comment":"Resources"},{"value":"1D60588E0D05DD3D006BFB54","comment":"Sources"},{"value":"1D60588F0D05DD3D006BFB54","comment":"Frameworks"}],"buildRules":[],"dependencies":[{"value":"301BF551109A68C00062928A","comment":"PBXTargetDependency"}],"name":"\"KitchenSinktablet\"","productName":"\"KitchenSinktablet\"","productReference":"1D6058910D05DD3D006BFB54","productReference_comment":"KitchenSinktablet.app","productType":"\"com.apple.product-type.application\""},"1D6058900D05DD3D006BFB54_comment":"KitchenSinktablet","1D6058900D05DD3D006BFB55":{"isa":"PBXNativeTarget","buildConfigurationList":"1D6058960D05DD3E006BFB54","buildConfigurationList_comment":"Build configuration list for PBXNativeTarget \"TestApp\"","buildPhases":[{"value":"304B58A110DAC018002A0835","comment":"Touch www folder"},{"value":"1D60588D0D05DD3D006BFB54","comment":"Resources"},{"value":"1D60588E0D05DD3D006BFB54","comment":"Sources"},{"value":"1D60588F0D05DD3D006BFB54","comment":"Frameworks"}],"buildRules":[],"dependencies":[],"name":"\"TestApp\"","productName":"\"TestApp\"","productReference":"1D6058910D05DD3D006BFB54","productReference_comment":"TestApp.app","productType":"\"com.apple.product-type.application\""},"1D6058900D05DD3D006BFB55_comment":"TestApp"},"PBXProject":{"29B97313FDCFA39411CA2CEA":{"isa":"PBXProject","buildConfigurationList":"C01FCF4E08A954540054247B","buildConfigurationList_comment":"Build configuration list for PBXProject \"KitchenSinktablet\"","compatibilityVersion":"\"Xcode 3.1\"","developmentRegion":"English","hasScannedForEncodings":1,"knownRegions":["English","Japanese","French","German","en","es"],"mainGroup":"29B97314FDCFA39411CA2CEA","mainGroup_comment":"CustomTemplate","projectDirPath":"\"\"","projectReferences":[{"ProductGroup":"301BF52E109A57CC0062928A","ProductGroup_comment":"Products","ProjectRef":"301BF52D109A57CC0062928A","ProjectRef_comment":"PhoneGapLib.xcodeproj"}],"projectRoot":"\"\"","targets":[{"value":"1D6058900D05DD3D006BFB54","comment":"KitchenSinktablet"},{"value":"1D6058900D05DD3D006BFB55","comment":"TestApp"}]},"29B97313FDCFA39411CA2CEA_comment":"Project object"},"PBXReferenceProxy":{"301BF535109A57CC0062928A":{"isa":"PBXReferenceProxy","fileType":"archive.ar","path":"libPhoneGap.a","remoteRef":"301BF534109A57CC0062928A","remoteRef_comment":"PBXContainerItemProxy","sourceTree":"BUILT_PRODUCTS_DIR"},"301BF535109A57CC0062928A_comment":"libPhoneGap.a","30E47BC3136F595F00DBB853":{"isa":"PBXReferenceProxy","fileType":"wrapper.cfbundle","path":"PhoneGap.framework","remoteRef":"30E47BC2136F595F00DBB853","remoteRef_comment":"PBXContainerItemProxy","sourceTree":"BUILT_PRODUCTS_DIR"},"30E47BC3136F595F00DBB853_comment":"PhoneGap.framework"},"PBXResourcesBuildPhase":{"1D60588D0D05DD3D006BFB54":{"isa":"PBXResourcesBuildPhase","buildActionMask":2147483647,"files":[{"value":"301BF570109A69640062928A","comment":"www in Resources"},{"value":"3053AC6F109B7857006FCFE7","comment":"VERSION in Resources"},{"value":"30E1352710E2C1420031B30D","comment":"PhoneGap.plist in Resources"},{"value":"307D28A2123043360040C0FA","comment":"PhoneGapBuildSettings.xcconfig in Resources"},{"value":"308D05371370CCF300D202BF","comment":"icon-72.png in Resources"},{"value":"308D05381370CCF300D202BF","comment":"icon.png in Resources"},{"value":"308D05391370CCF300D202BF","comment":"icon@2x.png in Resources"},{"value":"308D053C1370CCF300D202BF","comment":"Default.png in Resources"},{"value":"308D053D1370CCF300D202BF","comment":"Default@2x.png in Resources"},{"value":"3072F99713A8081B00425683","comment":"Capture.bundle in Resources"},{"value":"1F766FE113BBADB100FB74C0","comment":"Localizable.strings in Resources"},{"value":"1F766FE213BBADB100FB74C0","comment":"Localizable.strings in Resources"}],"runOnlyForDeploymentPostprocessing":0},"1D60588D0D05DD3D006BFB54_comment":"Resources"},"PBXShellScriptBuildPhase":{"304B58A110DAC018002A0835":{"isa":"PBXShellScriptBuildPhase","buildActionMask":2147483647,"files":[],"inputPaths":[],"name":"\"Touch www folder\"","outputPaths":[],"runOnlyForDeploymentPostprocessing":0,"shellPath":"/bin/sh","shellScript":"\"touch -cm ${PROJECT_DIR}/www\""},"304B58A110DAC018002A0835_comment":"Touch www folder"},"PBXSourcesBuildPhase":{"1D60588E0D05DD3D006BFB54":{"isa":"PBXSourcesBuildPhase","buildActionMask":2147483647,"files":[{"value":"1D60589B0D05DD56006BFB54","comment":"main.m in Sources"},{"value":"1D3623260D0F684500981E51","comment":"AppDelegate.m in Sources"}],"runOnlyForDeploymentPostprocessing":0},"1D60588E0D05DD3D006BFB54_comment":"Sources"},"PBXTargetDependency":{"301BF551109A68C00062928A":{"isa":"PBXTargetDependency","name":"PhoneGapLib","targetProxy":"301BF550109A68C00062928A","targetProxy_comment":"PBXContainerItemProxy"},"301BF551109A68C00062928A_comment":"PBXTargetDependency"},"PBXVariantGroup":{"1F766FDC13BBADB100FB74C0":{"isa":"PBXVariantGroup","children":[{"value":"1F766FDD13BBADB100FB74C0","comment":"en"}],"name":"Localizable.strings","sourceTree":"\"<group>\""},"1F766FDC13BBADB100FB74C0_comment":"Localizable.strings","1F766FDF13BBADB100FB74C0":{"isa":"PBXVariantGroup","children":[{"value":"1F766FE013BBADB100FB74C0","comment":"es"}],"name":"Localizable.strings","sourceTree":"\"<group>\""},"1F766FDF13BBADB100FB74C0_comment":"Localizable.strings"},"XCBuildConfiguration":{"1D6058940D05DD3E006BFB54":{"isa":"XCBuildConfiguration","buildSettings":{"ALWAYS_SEARCH_USER_PATHS":"NO","ARCHS":["armv6","armv7"],"COPY_PHASE_STRIP":"NO","GCC_DYNAMIC_NO_PIC":"NO","GCC_OPTIMIZATION_LEVEL":0,"GCC_PRECOMPILE_PREFIX_HEADER":"YES","GCC_PREFIX_HEADER":"\"KitchenSinktablet-Prefix.pch\"","INFOPLIST_FILE":"\"KitchenSinktablet-Info.plist\"","IPHONEOS_DEPLOYMENT_TARGET":"3.0","ONLY_ACTIVE_ARCH":"NO","PRODUCT_NAME":"\"KitchenSinktablet\"","TARGETED_DEVICE_FAMILY":"\"1,2\""},"name":"Debug"},"1D6058940D05DD3E006BFB54_comment":"Debug","1D6058950D05DD3E006BFB54":{"isa":"XCBuildConfiguration","buildSettings":{"ALWAYS_SEARCH_USER_PATHS":"NO","ARCHS":["armv6","armv7"],"COPY_PHASE_STRIP":"YES","GCC_PRECOMPILE_PREFIX_HEADER":"YES","GCC_PREFIX_HEADER":"\"KitchenSinktablet-Prefix.pch\"","INFOPLIST_FILE":"\"KitchenSinktablet-Info.plist\"","IPHONEOS_DEPLOYMENT_TARGET":"3.0","ONLY_ACTIVE_ARCH":"NO","PRODUCT_NAME":"\"KitchenSinktablet\"","TARGETED_DEVICE_FAMILY":"\"1,2\""},"name":"Release"},"1D6058950D05DD3E006BFB54_comment":"Release","C01FCF4F08A954540054247B":{"isa":"XCBuildConfiguration","baseConfigurationReference":"307D28A1123043350040C0FA","baseConfigurationReference_comment":"PhoneGapBuildSettings.xcconfig","buildSettings":{"ARCHS":"\"$(ARCHS_STANDARD_32_BIT)\"","\"CODE_SIGN_IDENTITY[sdk=iphoneos*]\"":"\"iPhone Distribution\"","GCC_C_LANGUAGE_STANDARD":"c99","GCC_VERSION":"com.apple.compilers.llvmgcc42","GCC_WARN_ABOUT_RETURN_TYPE":"YES","GCC_WARN_UNUSED_VARIABLE":"YES","IPHONEOS_DEPLOYMENT_TARGET":"3.0","OTHER_LDFLAGS":["\"-weak_framework\"","UIKit","\"-weak_framework\"","AVFoundation","\"-weak_framework\"","CoreMedia","\"-weak_library\"","/usr/lib/libSystem.B.dylib","\"-all_load\"","\"-Obj-C\""],"PREBINDING":"NO","SDKROOT":"iphoneos","SKIP_INSTALL":"NO","USER_HEADER_SEARCH_PATHS":"\"\"$(PHONEGAPLIB)/Classes/JSON\" \"$(PHONEGAPLIB)/Classes\"\""},"name":"Debug"},"C01FCF4F08A954540054247B_comment":"Debug","C01FCF5008A954540054247B":{"isa":"XCBuildConfiguration","baseConfigurationReference":"307D28A1123043350040C0FA","baseConfigurationReference_comment":"PhoneGapBuildSettings.xcconfig","buildSettings":{"ARCHS":"\"$(ARCHS_STANDARD_32_BIT)\"","\"CODE_SIGN_IDENTITY[sdk=iphoneos*]\"":"\"iPhone Distribution\"","GCC_C_LANGUAGE_STANDARD":"c99","GCC_VERSION":"com.apple.compilers.llvmgcc42","GCC_WARN_ABOUT_RETURN_TYPE":"YES","GCC_WARN_UNUSED_VARIABLE":"YES","IPHONEOS_DEPLOYMENT_TARGET":"3.0","OTHER_LDFLAGS":["\"-weak_framework\"","UIKit","\"-weak_framework\"","AVFoundation","\"-weak_framework\"","CoreMedia","\"-weak_library\"","/usr/lib/libSystem.B.dylib","\"-all_load\"","\"-Obj-C\""],"PREBINDING":"NO","SDKROOT":"iphoneos","SKIP_INSTALL":"NO","USER_HEADER_SEARCH_PATHS":"\"\"$(PHONEGAPLIB)/Classes/JSON\" \"$(PHONEGAPLIB)/Classes\"\""},"name":"Release"},"C01FCF5008A954540054247B_comment":"Release"},"XCConfigurationList":{"1D6058960D05DD3E006BFB54":{"isa":"XCConfigurationList","buildConfigurations":[{"value":"1D6058940D05DD3E006BFB54","comment":"Debug"},{"value":"1D6058950D05DD3E006BFB54","comment":"Release"}],"defaultConfigurationIsVisible":0,"defaultConfigurationName":"Release"},"1D6058960D05DD3E006BFB54_comment":"Build configuration list for PBXNativeTarget \"KitchenSinktablet\"","C01FCF4E08A954540054247B":{"isa":"XCConfigurationList","buildConfigurations":[{"value":"C01FCF4F08A954540054247B","comment":"Debug"},{"value":"C01FCF5008A954540054247B","comment":"Release"}],"defaultConfigurationIsVisible":0,"defaultConfigurationName":"Release"},"C01FCF4E08A954540054247B_comment":"Build configuration list for PBXProject \"KitchenSinktablet\""}},"rootObject":"29B97313FDCFA39411CA2CEA","rootObject_comment":"Project object"},"headComment":"!$*UTF8*$!"}
+{
+  "project": {
+    "archiveVersion": 1,
+    "classes": {},
+    "objectVersion": 45,
+    "objects": {
+      "PBXBuildFile": {
+        "1D3623260D0F684500981E51": {
+          "isa": "PBXBuildFile",
+          "fileRef": "1D3623250D0F684500981E51",
+          "fileRef_comment": "AppDelegate.m"
+        },
+        "1D3623260D0F684500981E51_comment": "AppDelegate.m in Sources",
+        "1D60589B0D05DD56006BFB54": {
+          "isa": "PBXBuildFile",
+          "fileRef": "29B97316FDCFA39411CA2CEA",
+          "fileRef_comment": "main.m"
+        },
+        "1D60589B0D05DD56006BFB54_comment": "main.m in Sources",
+        "1D60589F0D05DD5A006BFB54": {
+          "isa": "PBXBuildFile",
+          "fileRef": "1D30AB110D05D00D00671497",
+          "fileRef_comment": "Foundation.framework"
+        },
+        "1D60589F0D05DD5A006BFB54_comment": "Foundation.framework in Frameworks",
+        "1DF5F4E00D08C38300B7A737": {
+          "isa": "PBXBuildFile",
+          "fileRef": "1DF5F4DF0D08C38300B7A737",
+          "fileRef_comment": "UIKit.framework",
+          "settings": {
+            "ATTRIBUTES": [
+              "Weak"
+            ]
+          }
+        },
+        "1DF5F4E00D08C38300B7A737_comment": "UIKit.framework in Frameworks",
+        "1F766FE113BBADB100FB74C0": {
+          "isa": "PBXBuildFile",
+          "fileRef": "1F766FDC13BBADB100FB74C0",
+          "fileRef_comment": "Localizable.strings"
+        },
+        "1F766FE113BBADB100FB74C0_comment": "Localizable.strings in Resources",
+        "1F766FE213BBADB100FB74C0": {
+          "isa": "PBXBuildFile",
+          "fileRef": "1F766FDF13BBADB100FB74C0",
+          "fileRef_comment": "Localizable.strings"
+        },
+        "1F766FE213BBADB100FB74C0_comment": "Localizable.strings in Resources",
+        "288765FD0DF74451002DB57D": {
+          "isa": "PBXBuildFile",
+          "fileRef": "288765FC0DF74451002DB57D",
+          "fileRef_comment": "CoreGraphics.framework"
+        },
+        "288765FD0DF74451002DB57D_comment": "CoreGraphics.framework in Frameworks",
+        "301BF552109A68D80062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF535109A57CC0062928A",
+          "fileRef_comment": "libPhoneGap.a"
+        },
+        "301BF552109A68D80062928A_comment": "libPhoneGap.a in Frameworks",
+        "301BF570109A69640062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF56E109A69640062928A",
+          "fileRef_comment": "www"
+        },
+        "301BF570109A69640062928A_comment": "www in Resources",
+        "301BF5B5109A6A2B0062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF5B4109A6A2B0062928A",
+          "fileRef_comment": "AddressBook.framework"
+        },
+        "301BF5B5109A6A2B0062928A_comment": "AddressBook.framework in Frameworks",
+        "301BF5B7109A6A2B0062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF5B6109A6A2B0062928A",
+          "fileRef_comment": "AddressBookUI.framework"
+        },
+        "301BF5B7109A6A2B0062928A_comment": "AddressBookUI.framework in Frameworks",
+        "301BF5B9109A6A2B0062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF5B8109A6A2B0062928A",
+          "fileRef_comment": "AudioToolbox.framework"
+        },
+        "301BF5B9109A6A2B0062928A_comment": "AudioToolbox.framework in Frameworks",
+        "301BF5BB109A6A2B0062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF5BA109A6A2B0062928A",
+          "fileRef_comment": "AVFoundation.framework",
+          "settings": {
+            "ATTRIBUTES": [
+              "Weak"
+            ]
+          }
+        },
+        "301BF5BB109A6A2B0062928A_comment": "AVFoundation.framework in Frameworks",
+        "301BF5BD109A6A2B0062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF5BC109A6A2B0062928A",
+          "fileRef_comment": "CFNetwork.framework"
+        },
+        "301BF5BD109A6A2B0062928A_comment": "CFNetwork.framework in Frameworks",
+        "301BF5BF109A6A2B0062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF5BE109A6A2B0062928A",
+          "fileRef_comment": "CoreLocation.framework"
+        },
+        "301BF5BF109A6A2B0062928A_comment": "CoreLocation.framework in Frameworks",
+        "301BF5C1109A6A2B0062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF5C0109A6A2B0062928A",
+          "fileRef_comment": "MediaPlayer.framework"
+        },
+        "301BF5C1109A6A2B0062928A_comment": "MediaPlayer.framework in Frameworks",
+        "301BF5C3109A6A2B0062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF5C2109A6A2B0062928A",
+          "fileRef_comment": "QuartzCore.framework"
+        },
+        "301BF5C3109A6A2B0062928A_comment": "QuartzCore.framework in Frameworks",
+        "301BF5C5109A6A2B0062928A": {
+          "isa": "PBXBuildFile",
+          "fileRef": "301BF5C4109A6A2B0062928A",
+          "fileRef_comment": "SystemConfiguration.framework"
+        },
+        "301BF5C5109A6A2B0062928A_comment": "SystemConfiguration.framework in Frameworks",
+        "3053AC6F109B7857006FCFE7": {
+          "isa": "PBXBuildFile",
+          "fileRef": "3053AC6E109B7857006FCFE7",
+          "fileRef_comment": "VERSION"
+        },
+        "3053AC6F109B7857006FCFE7_comment": "VERSION in Resources",
+        "305D5FD1115AB8F900A74A75": {
+          "isa": "PBXBuildFile",
+          "fileRef": "305D5FD0115AB8F900A74A75",
+          "fileRef_comment": "MobileCoreServices.framework"
+        },
+        "305D5FD1115AB8F900A74A75_comment": "MobileCoreServices.framework in Frameworks",
+        "3072F99713A8081B00425683": {
+          "isa": "PBXBuildFile",
+          "fileRef": "3072F99613A8081B00425683",
+          "fileRef_comment": "Capture.bundle"
+        },
+        "3072F99713A8081B00425683_comment": "Capture.bundle in Resources",
+        "307D28A2123043360040C0FA": {
+          "isa": "PBXBuildFile",
+          "fileRef": "307D28A1123043350040C0FA",
+          "fileRef_comment": "PhoneGapBuildSettings.xcconfig"
+        },
+        "307D28A2123043360040C0FA_comment": "PhoneGapBuildSettings.xcconfig in Resources",
+        "308D05371370CCF300D202BF": {
+          "isa": "PBXBuildFile",
+          "fileRef": "308D052E1370CCF300D202BF",
+          "fileRef_comment": "icon-72.png"
+        },
+        "308D05371370CCF300D202BF_comment": "icon-72.png in Resources",
+        "308D05381370CCF300D202BF": {
+          "isa": "PBXBuildFile",
+          "fileRef": "308D052F1370CCF300D202BF",
+          "fileRef_comment": "icon.png"
+        },
+        "308D05381370CCF300D202BF_comment": "icon.png in Resources",
+        "308D05391370CCF300D202BF": {
+          "isa": "PBXBuildFile",
+          "fileRef": "308D05301370CCF300D202BF",
+          "fileRef_comment": "icon@2x.png"
+        },
+        "308D05391370CCF300D202BF_comment": "icon@2x.png in Resources",
+        "308D053C1370CCF300D202BF": {
+          "isa": "PBXBuildFile",
+          "fileRef": "308D05341370CCF300D202BF",
+          "fileRef_comment": "Default.png"
+        },
+        "308D053C1370CCF300D202BF_comment": "Default.png in Resources",
+        "308D053D1370CCF300D202BF": {
+          "isa": "PBXBuildFile",
+          "fileRef": "308D05351370CCF300D202BF",
+          "fileRef_comment": "Default@2x.png"
+        },
+        "308D053D1370CCF300D202BF_comment": "Default@2x.png in Resources",
+        "30E1352710E2C1420031B30D": {
+          "isa": "PBXBuildFile",
+          "fileRef": "30E1352610E2C1420031B30D",
+          "fileRef_comment": "PhoneGap.plist"
+        },
+        "30E1352710E2C1420031B30D_comment": "PhoneGap.plist in Resources",
+        "30E5649213A7FCAF007403D8": {
+          "isa": "PBXBuildFile",
+          "fileRef": "30E5649113A7FCAF007403D8",
+          "fileRef_comment": "CoreMedia.framework",
+          "settings": {
+            "ATTRIBUTES": [
+              "Weak"
+            ]
+          }
+        },
+        "30E5649213A7FCAF007403D8_comment": "CoreMedia.framework in Frameworks"
+      },
+      "PBXContainerItemProxy": {
+        "301BF534109A57CC0062928A": {
+          "isa": "PBXContainerItemProxy",
+          "containerPortal": "301BF52D109A57CC0062928A",
+          "containerPortal_comment": "PhoneGapLib.xcodeproj",
+          "proxyType": 2,
+          "remoteGlobalIDString": "D2AAC07E0554694100DB518D",
+          "remoteInfo": "PhoneGapLib"
+        },
+        "301BF534109A57CC0062928A_comment": "PBXContainerItemProxy",
+        "301BF550109A68C00062928A": {
+          "isa": "PBXContainerItemProxy",
+          "containerPortal": "301BF52D109A57CC0062928A",
+          "containerPortal_comment": "PhoneGapLib.xcodeproj",
+          "proxyType": 1,
+          "remoteGlobalIDString": "D2AAC07D0554694100DB518D",
+          "remoteInfo": "PhoneGapLib"
+        },
+        "301BF550109A68C00062928A_comment": "PBXContainerItemProxy",
+        "30E47BC2136F595F00DBB853": {
+          "isa": "PBXContainerItemProxy",
+          "containerPortal": "301BF52D109A57CC0062928A",
+          "containerPortal_comment": "PhoneGapLib.xcodeproj",
+          "proxyType": 2,
+          "remoteGlobalIDString": "303258D8136B2C9400982B63",
+          "remoteInfo": "PhoneGap"
+        },
+        "30E47BC2136F595F00DBB853_comment": "PBXContainerItemProxy"
+      },
+      "PBXCopyFilesBuildPhase": {
+        "73E82FF51BCF133B004E733B": {
+          "isa": "PBXCopyFilesBuildPhase",
+          "buildActionMask": 2147483647,
+          "dstPath": "\"\"",
+          "dstSubfolderSpec": 10,
+          "files": [],
+          "name": "\"Embed Frameworks\"",
+          "runOnlyForDeploymentPostprocessing": 0
+        },
+        "73E82FF51BCF133B004E733B_comment": "Embed Frameworks"
+      },
+      "PBXFileReference": {
+        "1D30AB110D05D00D00671497": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "Foundation.framework",
+          "path": "System/Library/Frameworks/Foundation.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "1D30AB110D05D00D00671497_comment": "Foundation.framework",
+        "1D3623240D0F684500981E51": {
+          "isa": "PBXFileReference",
+          "fileEncoding": 4,
+          "lastKnownFileType": "sourcecode.c.h",
+          "path": "AppDelegate.h",
+          "sourceTree": "\"<group>\""
+        },
+        "1D3623240D0F684500981E51_comment": "AppDelegate.h",
+        "1D3623250D0F684500981E51": {
+          "isa": "PBXFileReference",
+          "fileEncoding": 4,
+          "lastKnownFileType": "sourcecode.c.objc",
+          "path": "AppDelegate.m",
+          "sourceTree": "\"<group>\""
+        },
+        "1D3623250D0F684500981E51_comment": "AppDelegate.m",
+        "1D6058910D05DD3D006BFB54": {
+          "isa": "PBXFileReference",
+          "explicitFileType": "wrapper.application",
+          "includeInIndex": 0,
+          "path": "\"KitchenSinktablet.app\"",
+          "sourceTree": "BUILT_PRODUCTS_DIR"
+        },
+        "1D6058910D05DD3D006BFB54_comment": "KitchenSinktablet.app",
+        "1DF5F4DF0D08C38300B7A737": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "UIKit.framework",
+          "path": "System/Library/Frameworks/UIKit.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "1DF5F4DF0D08C38300B7A737_comment": "UIKit.framework",
+        "1F766FDD13BBADB100FB74C0": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "text.plist.strings",
+          "name": "en",
+          "path": "Localizable.strings",
+          "sourceTree": "\"<group>\""
+        },
+        "1F766FDD13BBADB100FB74C0_comment": "en",
+        "1F766FE013BBADB100FB74C0": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "text.plist.strings",
+          "name": "es",
+          "path": "Localizable.strings",
+          "sourceTree": "\"<group>\""
+        },
+        "1F766FE013BBADB100FB74C0_comment": "es",
+        "288765FC0DF74451002DB57D": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "CoreGraphics.framework",
+          "path": "System/Library/Frameworks/CoreGraphics.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "288765FC0DF74451002DB57D_comment": "CoreGraphics.framework",
+        "29B97316FDCFA39411CA2CEA": {
+          "isa": "PBXFileReference",
+          "fileEncoding": 4,
+          "lastKnownFileType": "sourcecode.c.objc",
+          "path": "main.m",
+          "sourceTree": "\"<group>\""
+        },
+        "29B97316FDCFA39411CA2CEA_comment": "main.m",
+        "301BF52D109A57CC0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "\"wrapper.pb-project\"",
+          "path": "PhoneGapLib.xcodeproj",
+          "sourceTree": "PHONEGAPLIB"
+        },
+        "301BF52D109A57CC0062928A_comment": "PhoneGapLib.xcodeproj",
+        "301BF56E109A69640062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "folder",
+          "path": "www",
+          "sourceTree": "SOURCE_ROOT"
+        },
+        "301BF56E109A69640062928A_comment": "www",
+        "301BF5B4109A6A2B0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "AddressBook.framework",
+          "path": "System/Library/Frameworks/AddressBook.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "301BF5B4109A6A2B0062928A_comment": "AddressBook.framework",
+        "301BF5B6109A6A2B0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "AddressBookUI.framework",
+          "path": "System/Library/Frameworks/AddressBookUI.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "301BF5B6109A6A2B0062928A_comment": "AddressBookUI.framework",
+        "301BF5B8109A6A2B0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "AudioToolbox.framework",
+          "path": "System/Library/Frameworks/AudioToolbox.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "301BF5B8109A6A2B0062928A_comment": "AudioToolbox.framework",
+        "301BF5BA109A6A2B0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "AVFoundation.framework",
+          "path": "System/Library/Frameworks/AVFoundation.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "301BF5BA109A6A2B0062928A_comment": "AVFoundation.framework",
+        "301BF5BC109A6A2B0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "CFNetwork.framework",
+          "path": "System/Library/Frameworks/CFNetwork.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "301BF5BC109A6A2B0062928A_comment": "CFNetwork.framework",
+        "301BF5BE109A6A2B0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "CoreLocation.framework",
+          "path": "System/Library/Frameworks/CoreLocation.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "301BF5BE109A6A2B0062928A_comment": "CoreLocation.framework",
+        "301BF5C0109A6A2B0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "MediaPlayer.framework",
+          "path": "System/Library/Frameworks/MediaPlayer.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "301BF5C0109A6A2B0062928A_comment": "MediaPlayer.framework",
+        "301BF5C2109A6A2B0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "QuartzCore.framework",
+          "path": "System/Library/Frameworks/QuartzCore.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "301BF5C2109A6A2B0062928A_comment": "QuartzCore.framework",
+        "301BF5C4109A6A2B0062928A": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "SystemConfiguration.framework",
+          "path": "System/Library/Frameworks/SystemConfiguration.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "301BF5C4109A6A2B0062928A_comment": "SystemConfiguration.framework",
+        "3053AC6E109B7857006FCFE7": {
+          "isa": "PBXFileReference",
+          "fileEncoding": 4,
+          "lastKnownFileType": "text",
+          "path": "VERSION",
+          "sourceTree": "PHONEGAPLIB"
+        },
+        "3053AC6E109B7857006FCFE7_comment": "VERSION",
+        "305D5FD0115AB8F900A74A75": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "MobileCoreServices.framework",
+          "path": "System/Library/Frameworks/MobileCoreServices.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "305D5FD0115AB8F900A74A75_comment": "MobileCoreServices.framework",
+        "3072F99613A8081B00425683": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "\"wrapper.plug-in\"",
+          "name": "Capture.bundle",
+          "path": "Resources/Capture.bundle",
+          "sourceTree": "\"<group>\""
+        },
+        "3072F99613A8081B00425683_comment": "Capture.bundle",
+        "307D28A1123043350040C0FA": {
+          "isa": "PBXFileReference",
+          "fileEncoding": 4,
+          "lastKnownFileType": "text.xcconfig",
+          "path": "PhoneGapBuildSettings.xcconfig",
+          "sourceTree": "\"<group>\""
+        },
+        "307D28A1123043350040C0FA_comment": "PhoneGapBuildSettings.xcconfig",
+        "308D052E1370CCF300D202BF": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "image.png",
+          "path": "\"icon-72.png\"",
+          "sourceTree": "\"<group>\""
+        },
+        "308D052E1370CCF300D202BF_comment": "icon-72.png",
+        "308D052F1370CCF300D202BF": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "image.png",
+          "path": "icon.png",
+          "sourceTree": "\"<group>\""
+        },
+        "308D052F1370CCF300D202BF_comment": "icon.png",
+        "308D05301370CCF300D202BF": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "image.png",
+          "path": "\"icon@2x.png\"",
+          "sourceTree": "\"<group>\""
+        },
+        "308D05301370CCF300D202BF_comment": "icon@2x.png",
+        "308D05341370CCF300D202BF": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "image.png",
+          "path": "Default.png",
+          "sourceTree": "\"<group>\""
+        },
+        "308D05341370CCF300D202BF_comment": "Default.png",
+        "308D05351370CCF300D202BF": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "image.png",
+          "path": "\"Default@2x.png\"",
+          "sourceTree": "\"<group>\""
+        },
+        "308D05351370CCF300D202BF_comment": "Default@2x.png",
+        "30E1352610E2C1420031B30D": {
+          "isa": "PBXFileReference",
+          "fileEncoding": 4,
+          "lastKnownFileType": "text.plist.xml",
+          "path": "PhoneGap.plist",
+          "sourceTree": "\"<group>\""
+        },
+        "30E1352610E2C1420031B30D_comment": "PhoneGap.plist",
+        "30E5649113A7FCAF007403D8": {
+          "isa": "PBXFileReference",
+          "lastKnownFileType": "wrapper.framework",
+          "name": "CoreMedia.framework",
+          "path": "System/Library/Frameworks/CoreMedia.framework",
+          "sourceTree": "SDKROOT"
+        },
+        "30E5649113A7FCAF007403D8_comment": "CoreMedia.framework",
+        "32CA4F630368D1EE00C91783": {
+          "isa": "PBXFileReference",
+          "fileEncoding": 4,
+          "lastKnownFileType": "sourcecode.c.h",
+          "path": "\"KitchenSinktablet-Prefix.pch\"",
+          "sourceTree": "\"<group>\""
+        },
+        "32CA4F630368D1EE00C91783_comment": "KitchenSinktablet-Prefix.pch",
+        "8D1107310486CEB800E47090": {
+          "isa": "PBXFileReference",
+          "fileEncoding": 4,
+          "lastKnownFileType": "text.plist.xml",
+          "path": "\"KitchenSinktablet-Info.plist\"",
+          "plistStructureDefinitionIdentifier": "\"com.apple.xcode.plist.structure-definition.iphone.info-plist\"",
+          "sourceTree": "\"<group>\""
+        },
+        "8D1107310486CEB800E47090_comment": "KitchenSinktablet-Info.plist"
+      },
+      "PBXFrameworksBuildPhase": {
+        "1D60588F0D05DD3D006BFB54": {
+          "isa": "PBXFrameworksBuildPhase",
+          "buildActionMask": 2147483647,
+          "files": [
+            {
+              "value": "301BF552109A68D80062928A",
+              "comment": "libPhoneGap.a in Frameworks"
+            },
+            {
+              "value": "1D60589F0D05DD5A006BFB54",
+              "comment": "Foundation.framework in Frameworks"
+            },
+            {
+              "value": "1DF5F4E00D08C38300B7A737",
+              "comment": "UIKit.framework in Frameworks"
+            },
+            {
+              "value": "288765FD0DF74451002DB57D",
+              "comment": "CoreGraphics.framework in Frameworks"
+            },
+            {
+              "value": "301BF5B5109A6A2B0062928A",
+              "comment": "AddressBook.framework in Frameworks"
+            },
+            {
+              "value": "301BF5B7109A6A2B0062928A",
+              "comment": "AddressBookUI.framework in Frameworks"
+            },
+            {
+              "value": "301BF5B9109A6A2B0062928A",
+              "comment": "AudioToolbox.framework in Frameworks"
+            },
+            {
+              "value": "301BF5BB109A6A2B0062928A",
+              "comment": "AVFoundation.framework in Frameworks"
+            },
+            {
+              "value": "301BF5BD109A6A2B0062928A",
+              "comment": "CFNetwork.framework in Frameworks"
+            },
+            {
+              "value": "301BF5BF109A6A2B0062928A",
+              "comment": "CoreLocation.framework in Frameworks"
+            },
+            {
+              "value": "301BF5C1109A6A2B0062928A",
+              "comment": "MediaPlayer.framework in Frameworks"
+            },
+            {
+              "value": "301BF5C3109A6A2B0062928A",
+              "comment": "QuartzCore.framework in Frameworks"
+            },
+            {
+              "value": "301BF5C5109A6A2B0062928A",
+              "comment": "SystemConfiguration.framework in Frameworks"
+            },
+            {
+              "value": "305D5FD1115AB8F900A74A75",
+              "comment": "MobileCoreServices.framework in Frameworks"
+            },
+            {
+              "value": "30E5649213A7FCAF007403D8",
+              "comment": "CoreMedia.framework in Frameworks"
+            }
+          ],
+          "runOnlyForDeploymentPostprocessing": 0
+        },
+        "1D60588F0D05DD3D006BFB54_comment": "Frameworks"
+      },
+      "PBXGroup": {
+        "080E96DDFE201D6D7F000001": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "1D3623240D0F684500981E51",
+              "comment": "AppDelegate.h"
+            },
+            {
+              "value": "1D3623250D0F684500981E51",
+              "comment": "AppDelegate.m"
+            }
+          ],
+          "path": "Classes",
+          "sourceTree": "SOURCE_ROOT"
+        },
+        "080E96DDFE201D6D7F000001_comment": "Classes",
+        "19C28FACFE9D520D11CA2CBB": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "1D6058910D05DD3D006BFB54",
+              "comment": "KitchenSinktablet.app"
+            }
+          ],
+          "name": "Products",
+          "sourceTree": "\"<group>\""
+        },
+        "19C28FACFE9D520D11CA2CBB_comment": "Products",
+        "1F766FDB13BBADB100FB74C0": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "1F766FDC13BBADB100FB74C0",
+              "comment": "Localizable.strings"
+            }
+          ],
+          "name": "en.lproj",
+          "path": "Resources/en.lproj",
+          "sourceTree": "\"<group>\""
+        },
+        "1F766FDB13BBADB100FB74C0_comment": "en.lproj",
+        "1F766FDE13BBADB100FB74C0": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "1F766FDF13BBADB100FB74C0",
+              "comment": "Localizable.strings"
+            }
+          ],
+          "name": "es.lproj",
+          "path": "Resources/es.lproj",
+          "sourceTree": "\"<group>\""
+        },
+        "1F766FDE13BBADB100FB74C0_comment": "es.lproj",
+        "29B97314FDCFA39411CA2CEA": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "301BF56E109A69640062928A",
+              "comment": "www"
+            },
+            {
+              "value": "301BF52D109A57CC0062928A",
+              "comment": "PhoneGapLib.xcodeproj"
+            },
+            {
+              "value": "080E96DDFE201D6D7F000001",
+              "comment": "Classes"
+            },
+            {
+              "value": "307C750510C5A3420062BCA9",
+              "comment": "Plugins"
+            },
+            {
+              "value": "29B97315FDCFA39411CA2CEA",
+              "comment": "Other Sources"
+            },
+            {
+              "value": "29B97317FDCFA39411CA2CEA",
+              "comment": "Resources"
+            },
+            {
+              "value": "29B97323FDCFA39411CA2CEA",
+              "comment": "Frameworks"
+            },
+            {
+              "value": "19C28FACFE9D520D11CA2CBB",
+              "comment": "Products"
+            }
+          ],
+          "name": "CustomTemplate",
+          "sourceTree": "\"<group>\""
+        },
+        "29B97314FDCFA39411CA2CEA_comment": "CustomTemplate",
+        "29B97315FDCFA39411CA2CEA": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "32CA4F630368D1EE00C91783",
+              "comment": "KitchenSinktablet-Prefix.pch"
+            },
+            {
+              "value": "29B97316FDCFA39411CA2CEA",
+              "comment": "main.m"
+            }
+          ],
+          "name": "\"Other Sources\"",
+          "sourceTree": "\"<group>\""
+        },
+        "29B97315FDCFA39411CA2CEA_comment": "Other Sources",
+        "29B97317FDCFA39411CA2CEA": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "1F766FDB13BBADB100FB74C0",
+              "comment": "en.lproj"
+            },
+            {
+              "value": "1F766FDE13BBADB100FB74C0",
+              "comment": "es.lproj"
+            },
+            {
+              "value": "3072F99613A8081B00425683",
+              "comment": "Capture.bundle"
+            },
+            {
+              "value": "308D052D1370CCF300D202BF",
+              "comment": "icons"
+            },
+            {
+              "value": "308D05311370CCF300D202BF",
+              "comment": "splash"
+            },
+            {
+              "value": "30E1352610E2C1420031B30D",
+              "comment": "PhoneGap.plist"
+            },
+            {
+              "value": "3053AC6E109B7857006FCFE7",
+              "comment": "VERSION"
+            },
+            {
+              "value": "8D1107310486CEB800E47090",
+              "comment": "KitchenSinktablet-Info.plist"
+            },
+            {
+              "value": "307D28A1123043350040C0FA",
+              "comment": "PhoneGapBuildSettings.xcconfig"
+            }
+          ],
+          "name": "Resources",
+          "sourceTree": "\"<group>\""
+        },
+        "29B97317FDCFA39411CA2CEA_comment": "Resources",
+        "29B97323FDCFA39411CA2CEA": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "1DF5F4DF0D08C38300B7A737",
+              "comment": "UIKit.framework"
+            },
+            {
+              "value": "1D30AB110D05D00D00671497",
+              "comment": "Foundation.framework"
+            },
+            {
+              "value": "288765FC0DF74451002DB57D",
+              "comment": "CoreGraphics.framework"
+            },
+            {
+              "value": "301BF5B4109A6A2B0062928A",
+              "comment": "AddressBook.framework"
+            },
+            {
+              "value": "301BF5B6109A6A2B0062928A",
+              "comment": "AddressBookUI.framework"
+            },
+            {
+              "value": "301BF5B8109A6A2B0062928A",
+              "comment": "AudioToolbox.framework"
+            },
+            {
+              "value": "301BF5BA109A6A2B0062928A",
+              "comment": "AVFoundation.framework"
+            },
+            {
+              "value": "301BF5BC109A6A2B0062928A",
+              "comment": "CFNetwork.framework"
+            },
+            {
+              "value": "301BF5BE109A6A2B0062928A",
+              "comment": "CoreLocation.framework"
+            },
+            {
+              "value": "301BF5C0109A6A2B0062928A",
+              "comment": "MediaPlayer.framework"
+            },
+            {
+              "value": "301BF5C2109A6A2B0062928A",
+              "comment": "QuartzCore.framework"
+            },
+            {
+              "value": "301BF5C4109A6A2B0062928A",
+              "comment": "SystemConfiguration.framework"
+            },
+            {
+              "value": "305D5FD0115AB8F900A74A75",
+              "comment": "MobileCoreServices.framework"
+            },
+            {
+              "value": "30E5649113A7FCAF007403D8",
+              "comment": "CoreMedia.framework"
+            }
+          ],
+          "name": "Frameworks",
+          "sourceTree": "\"<group>\""
+        },
+        "29B97323FDCFA39411CA2CEA_comment": "Frameworks",
+        "301BF52E109A57CC0062928A": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "301BF535109A57CC0062928A",
+              "comment": "libPhoneGap.a"
+            },
+            {
+              "value": "30E47BC3136F595F00DBB853",
+              "comment": "PhoneGap.framework"
+            }
+          ],
+          "name": "Products",
+          "sourceTree": "\"<group>\""
+        },
+        "301BF52E109A57CC0062928A_comment": "Products",
+        "307C750510C5A3420062BCA9": {
+          "isa": "PBXGroup",
+          "children": [],
+          "path": "Plugins",
+          "sourceTree": "SOURCE_ROOT"
+        },
+        "307C750510C5A3420062BCA9_comment": "Plugins",
+        "308D052D1370CCF300D202BF": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "308D052E1370CCF300D202BF",
+              "comment": "icon-72.png"
+            },
+            {
+              "value": "308D052F1370CCF300D202BF",
+              "comment": "icon.png"
+            },
+            {
+              "value": "308D05301370CCF300D202BF",
+              "comment": "icon@2x.png"
+            }
+          ],
+          "name": "icons",
+          "path": "Resources/icons",
+          "sourceTree": "\"<group>\""
+        },
+        "308D052D1370CCF300D202BF_comment": "icons",
+        "308D05311370CCF300D202BF": {
+          "isa": "PBXGroup",
+          "children": [
+            {
+              "value": "308D05341370CCF300D202BF",
+              "comment": "Default.png"
+            },
+            {
+              "value": "308D05351370CCF300D202BF",
+              "comment": "Default@2x.png"
+            }
+          ],
+          "name": "splash",
+          "path": "Resources/splash",
+          "sourceTree": "\"<group>\""
+        },
+        "308D05311370CCF300D202BF_comment": "splash"
+      },
+      "PBXNativeTarget": {
+        "1D6058900D05DD3D006BFB54": {
+          "isa": "PBXNativeTarget",
+          "buildConfigurationList": "1D6058960D05DD3E006BFB54",
+          "buildConfigurationList_comment": "Build configuration list for PBXNativeTarget \"KitchenSinktablet\"",
+          "buildPhases": [
+            {
+              "value": "304B58A110DAC018002A0835",
+              "comment": "Touch www folder"
+            },
+            {
+              "value": "1D60588D0D05DD3D006BFB54",
+              "comment": "Resources"
+            },
+            {
+              "value": "1D60588E0D05DD3D006BFB54",
+              "comment": "Sources"
+            },
+            {
+              "value": "1D60588F0D05DD3D006BFB54",
+              "comment": "Frameworks"
+            }
+          ],
+          "buildRules": [],
+          "dependencies": [
+            {
+              "value": "301BF551109A68C00062928A",
+              "comment": "PBXTargetDependency"
+            }
+          ],
+          "name": "\"KitchenSinktablet\"",
+          "productName": "\"KitchenSinktablet\"",
+          "productReference": "1D6058910D05DD3D006BFB54",
+          "productReference_comment": "KitchenSinktablet.app",
+          "productType": "\"com.apple.product-type.application\""
+        },
+        "1D6058900D05DD3D006BFB54_comment": "KitchenSinktablet",
+        "1D6058900D05DD3D006BFB55": {
+          "isa": "PBXNativeTarget",
+          "buildConfigurationList": "1D6058960D05DD3E006BFB54",
+          "buildConfigurationList_comment": "Build configuration list for PBXNativeTarget \"TestApp\"",
+          "buildPhases": [
+            {
+              "value": "304B58A110DAC018002A0835",
+              "comment": "Touch www folder"
+            },
+            {
+              "value": "1D60588D0D05DD3D006BFB54",
+              "comment": "Resources"
+            },
+            {
+              "value": "1D60588E0D05DD3D006BFB54",
+              "comment": "Sources"
+            },
+            {
+              "value": "1D60588F0D05DD3D006BFB54",
+              "comment": "Frameworks"
+            }
+          ],
+          "buildRules": [],
+          "dependencies": [],
+          "name": "\"TestApp\"",
+          "productName": "\"TestApp\"",
+          "productReference": "1D6058910D05DD3D006BFB54",
+          "productReference_comment": "TestApp.app",
+          "productType": "\"com.apple.product-type.application\""
+        },
+        "1D6058900D05DD3D006BFB55_comment": "TestApp"
+      },
+      "PBXProject": {
+        "29B97313FDCFA39411CA2CEA": {
+          "isa": "PBXProject",
+          "buildConfigurationList": "C01FCF4E08A954540054247B",
+          "buildConfigurationList_comment": "Build configuration list for PBXProject \"KitchenSinktablet\"",
+          "compatibilityVersion": "\"Xcode 3.1\"",
+          "developmentRegion": "English",
+          "hasScannedForEncodings": 1,
+          "knownRegions": [
+            "English",
+            "Japanese",
+            "French",
+            "German",
+            "en",
+            "es"
+          ],
+          "mainGroup": "29B97314FDCFA39411CA2CEA",
+          "mainGroup_comment": "CustomTemplate",
+          "projectDirPath": "\"\"",
+          "projectReferences": [
+            {
+              "ProductGroup": "301BF52E109A57CC0062928A",
+              "ProductGroup_comment": "Products",
+              "ProjectRef": "301BF52D109A57CC0062928A",
+              "ProjectRef_comment": "PhoneGapLib.xcodeproj"
+            }
+          ],
+          "projectRoot": "\"\"",
+          "targets": [
+            {
+              "value": "1D6058900D05DD3D006BFB54",
+              "comment": "KitchenSinktablet"
+            },
+            {
+              "value": "1D6058900D05DD3D006BFB55",
+              "comment": "TestApp"
+            }
+          ]
+        },
+        "29B97313FDCFA39411CA2CEA_comment": "Project object"
+      },
+      "PBXReferenceProxy": {
+        "301BF535109A57CC0062928A": {
+          "isa": "PBXReferenceProxy",
+          "fileType": "archive.ar",
+          "path": "libPhoneGap.a",
+          "remoteRef": "301BF534109A57CC0062928A",
+          "remoteRef_comment": "PBXContainerItemProxy",
+          "sourceTree": "BUILT_PRODUCTS_DIR"
+        },
+        "301BF535109A57CC0062928A_comment": "libPhoneGap.a",
+        "30E47BC3136F595F00DBB853": {
+          "isa": "PBXReferenceProxy",
+          "fileType": "wrapper.cfbundle",
+          "path": "PhoneGap.framework",
+          "remoteRef": "30E47BC2136F595F00DBB853",
+          "remoteRef_comment": "PBXContainerItemProxy",
+          "sourceTree": "BUILT_PRODUCTS_DIR"
+        },
+        "30E47BC3136F595F00DBB853_comment": "PhoneGap.framework"
+      },
+      "PBXResourcesBuildPhase": {
+        "1D60588D0D05DD3D006BFB54": {
+          "isa": "PBXResourcesBuildPhase",
+          "buildActionMask": 2147483647,
+          "files": [
+            {
+              "value": "301BF570109A69640062928A",
+              "comment": "www in Resources"
+            },
+            {
+              "value": "3053AC6F109B7857006FCFE7",
+              "comment": "VERSION in Resources"
+            },
+            {
+              "value": "30E1352710E2C1420031B30D",
+              "comment": "PhoneGap.plist in Resources"
+            },
+            {
+              "value": "307D28A2123043360040C0FA",
+              "comment": "PhoneGapBuildSettings.xcconfig in Resources"
+            },
+            {
+              "value": "308D05371370CCF300D202BF",
+              "comment": "icon-72.png in Resources"
+            },
+            {
+              "value": "308D05381370CCF300D202BF",
+              "comment": "icon.png in Resources"
+            },
+            {
+              "value": "308D05391370CCF300D202BF",
+              "comment": "icon@2x.png in Resources"
+            },
+            {
+              "value": "308D053C1370CCF300D202BF",
+              "comment": "Default.png in Resources"
+            },
+            {
+              "value": "308D053D1370CCF300D202BF",
+              "comment": "Default@2x.png in Resources"
+            },
+            {
+              "value": "3072F99713A8081B00425683",
+              "comment": "Capture.bundle in Resources"
+            },
+            {
+              "value": "1F766FE113BBADB100FB74C0",
+              "comment": "Localizable.strings in Resources"
+            },
+            {
+              "value": "1F766FE213BBADB100FB74C0",
+              "comment": "Localizable.strings in Resources"
+            }
+          ],
+          "runOnlyForDeploymentPostprocessing": 0
+        },
+        "1D60588D0D05DD3D006BFB54_comment": "Resources"
+      },
+      "PBXShellScriptBuildPhase": {
+        "304B58A110DAC018002A0835": {
+          "isa": "PBXShellScriptBuildPhase",
+          "buildActionMask": 2147483647,
+          "files": [],
+          "inputPaths": [],
+          "name": "\"Touch www folder\"",
+          "outputPaths": [],
+          "runOnlyForDeploymentPostprocessing": 0,
+          "shellPath": "/bin/sh",
+          "shellScript": "\"touch -cm ${PROJECT_DIR}/www\""
+        },
+        "304B58A110DAC018002A0835_comment": "Touch www folder"
+      },
+      "PBXSourcesBuildPhase": {
+        "1D60588E0D05DD3D006BFB54": {
+          "isa": "PBXSourcesBuildPhase",
+          "buildActionMask": 2147483647,
+          "files": [
+            {
+              "value": "1D60589B0D05DD56006BFB54",
+              "comment": "main.m in Sources"
+            },
+            {
+              "value": "1D3623260D0F684500981E51",
+              "comment": "AppDelegate.m in Sources"
+            }
+          ],
+          "runOnlyForDeploymentPostprocessing": 0
+        },
+        "1D60588E0D05DD3D006BFB54_comment": "Sources"
+      },
+      "PBXTargetDependency": {
+        "301BF551109A68C00062928A": {
+          "isa": "PBXTargetDependency",
+          "name": "PhoneGapLib",
+          "targetProxy": "301BF550109A68C00062928A",
+          "targetProxy_comment": "PBXContainerItemProxy"
+        },
+        "301BF551109A68C00062928A_comment": "PBXTargetDependency"
+      },
+      "PBXVariantGroup": {
+        "1F766FDC13BBADB100FB74C0": {
+          "isa": "PBXVariantGroup",
+          "children": [
+            {
+              "value": "1F766FDD13BBADB100FB74C0",
+              "comment": "en"
+            }
+          ],
+          "name": "Localizable.strings",
+          "sourceTree": "\"<group>\""
+        },
+        "1F766FDC13BBADB100FB74C0_comment": "Localizable.strings",
+        "1F766FDF13BBADB100FB74C0": {
+          "isa": "PBXVariantGroup",
+          "children": [
+            {
+              "value": "1F766FE013BBADB100FB74C0",
+              "comment": "es"
+            }
+          ],
+          "name": "Localizable.strings",
+          "sourceTree": "\"<group>\""
+        },
+        "1F766FDF13BBADB100FB74C0_comment": "Localizable.strings"
+      },
+      "XCBuildConfiguration": {
+        "1D6058940D05DD3E006BFB54": {
+          "isa": "XCBuildConfiguration",
+          "buildSettings": {
+            "ALWAYS_SEARCH_USER_PATHS": "NO",
+            "ARCHS": [
+              "armv6",
+              "armv7"
+            ],
+            "COPY_PHASE_STRIP": "NO",
+            "GCC_DYNAMIC_NO_PIC": "NO",
+            "GCC_OPTIMIZATION_LEVEL": 0,
+            "GCC_PRECOMPILE_PREFIX_HEADER": "YES",
+            "GCC_PREFIX_HEADER": "\"KitchenSinktablet-Prefix.pch\"",
+            "INFOPLIST_FILE": "\"KitchenSinktablet-Info.plist\"",
+            "IPHONEOS_DEPLOYMENT_TARGET": "3.0",
+            "ONLY_ACTIVE_ARCH": "NO",
+            "PRODUCT_NAME": "\"KitchenSinktablet\"",
+            "TARGETED_DEVICE_FAMILY": "\"1,2\""
+          },
+          "name": "Debug"
+        },
+        "1D6058940D05DD3E006BFB54_comment": "Debug",
+        "1D6058950D05DD3E006BFB54": {
+          "isa": "XCBuildConfiguration",
+          "buildSettings": {
+            "ALWAYS_SEARCH_USER_PATHS": "NO",
+            "ARCHS": [
+              "armv6",
+              "armv7"
+            ],
+            "COPY_PHASE_STRIP": "YES",
+            "GCC_PRECOMPILE_PREFIX_HEADER": "YES",
+            "GCC_PREFIX_HEADER": "\"KitchenSinktablet-Prefix.pch\"",
+            "INFOPLIST_FILE": "\"KitchenSinktablet-Info.plist\"",
+            "IPHONEOS_DEPLOYMENT_TARGET": "3.0",
+            "ONLY_ACTIVE_ARCH": "NO",
+            "PRODUCT_NAME": "\"KitchenSinktablet\"",
+            "TARGETED_DEVICE_FAMILY": "\"1,2\""
+          },
+          "name": "Release"
+        },
+        "1D6058950D05DD3E006BFB54_comment": "Release",
+        "C01FCF4F08A954540054247B": {
+          "isa": "XCBuildConfiguration",
+          "baseConfigurationReference": "307D28A1123043350040C0FA",
+          "baseConfigurationReference_comment": "PhoneGapBuildSettings.xcconfig",
+          "buildSettings": {
+            "ARCHS": "\"$(ARCHS_STANDARD_32_BIT)\"",
+            "\"CODE_SIGN_IDENTITY[sdk=iphoneos*]\"": "\"iPhone Distribution\"",
+            "GCC_C_LANGUAGE_STANDARD": "c99",
+            "GCC_VERSION": "com.apple.compilers.llvmgcc42",
+            "GCC_WARN_ABOUT_RETURN_TYPE": "YES",
+            "GCC_WARN_UNUSED_VARIABLE": "YES",
+            "IPHONEOS_DEPLOYMENT_TARGET": "3.0",
+            "OTHER_LDFLAGS": [
+              "\"-weak_framework\"",
+              "UIKit",
+              "\"-weak_framework\"",
+              "AVFoundation",
+              "\"-weak_framework\"",
+              "CoreMedia",
+              "\"-weak_library\"",
+              "/usr/lib/libSystem.B.dylib",
+              "\"-all_load\"",
+              "\"-Obj-C\""
+            ],
+            "PREBINDING": "NO",
+            "SDKROOT": "iphoneos",
+            "SKIP_INSTALL": "NO",
+            "USER_HEADER_SEARCH_PATHS": "\"\"$(PHONEGAPLIB)/Classes/JSON\" \"$(PHONEGAPLIB)/Classes\"\""
+          },
+          "name": "Debug"
+        },
+        "C01FCF4F08A954540054247B_comment": "Debug",
+        "C01FCF5008A954540054247B": {
+          "isa": "XCBuildConfiguration",
+          "baseConfigurationReference": "307D28A1123043350040C0FA",
+          "baseConfigurationReference_comment": "PhoneGapBuildSettings.xcconfig",
+          "buildSettings": {
+            "ARCHS": "\"$(ARCHS_STANDARD_32_BIT)\"",
+            "\"CODE_SIGN_IDENTITY[sdk=iphoneos*]\"": "\"iPhone Distribution\"",
+            "GCC_C_LANGUAGE_STANDARD": "c99",
+            "GCC_VERSION": "com.apple.compilers.llvmgcc42",
+            "GCC_WARN_ABOUT_RETURN_TYPE": "YES",
+            "GCC_WARN_UNUSED_VARIABLE": "YES",
+            "IPHONEOS_DEPLOYMENT_TARGET": "3.0",
+            "OTHER_LDFLAGS": [
+              "\"-weak_framework\"",
+              "UIKit",
+              "\"-weak_framework\"",
+              "AVFoundation",
+              "\"-weak_framework\"",
+              "CoreMedia",
+              "\"-weak_library\"",
+              "/usr/lib/libSystem.B.dylib",
+              "\"-all_load\"",
+              "\"-Obj-C\""
+            ],
+            "PREBINDING": "NO",
+            "SDKROOT": "iphoneos",
+            "SKIP_INSTALL": "NO",
+            "USER_HEADER_SEARCH_PATHS": "\"\"$(PHONEGAPLIB)/Classes/JSON\" \"$(PHONEGAPLIB)/Classes\"\""
+          },
+          "name": "Release"
+        },
+        "C01FCF5008A954540054247B_comment": "Release"
+      },
+      "XCConfigurationList": {
+        "1D6058960D05DD3E006BFB54": {
+          "isa": "XCConfigurationList",
+          "buildConfigurations": [
+            {
+              "value": "1D6058940D05DD3E006BFB54",
+              "comment": "Debug"
+            },
+            {
+              "value": "1D6058950D05DD3E006BFB54",
+              "comment": "Release"
+            }
+          ],
+          "defaultConfigurationIsVisible": 0,
+          "defaultConfigurationName": "Release"
+        },
+        "1D6058960D05DD3E006BFB54_comment": "Build configuration list for PBXNativeTarget \"KitchenSinktablet\"",
+        "C01FCF4E08A954540054247B": {
+          "isa": "XCConfigurationList",
+          "buildConfigurations": [
+            {
+              "value": "C01FCF4F08A954540054247B",
+              "comment": "Debug"
+            },
+            {
+              "value": "C01FCF5008A954540054247B",
+              "comment": "Release"
+            }
+          ],
+          "defaultConfigurationIsVisible": 0,
+          "defaultConfigurationName": "Release"
+        },
+        "C01FCF4E08A954540054247B_comment": "Build configuration list for PBXProject \"KitchenSinktablet\""
+      }
+    },
+    "rootObject": "29B97313FDCFA39411CA2CEA",
+    "rootObject_comment": "Project object"
+  },
+  "headComment": "!$*UTF8*$!"
+}
diff --git a/lib/pbxProject.js b/lib/pbxProject.js
index a295fe2..77b4530 100644
--- a/lib/pbxProject.js
+++ b/lib/pbxProject.js
@@ -270,13 +270,24 @@
 
     if (this.hasFile(file.path)) return false;
 
+    var customFramework = opt && opt.customFramework == true;
+    var link = !opt || (opt.link == undefined || opt.link);    //defaults to true if not specified
+    var embed = opt && opt.embed;                              //defaults to false if not specified
+
     this.addToPbxBuildFileSection(file);        // PBXBuildFile
     this.addToPbxFileReferenceSection(file);    // PBXFileReference
     this.addToFrameworksPbxGroup(file);         // PBXGroup
-    this.addToPbxFrameworksBuildPhase(file);    // PBXFrameworksBuildPhase
 
-    if (opt && opt.customFramework == true) {
+    if (link) {
+      this.addToPbxFrameworksBuildPhase(file);    // PBXFrameworksBuildPhase
+    }
+
+    if (customFramework) {
         this.addToFrameworkSearchPaths(file);
+
+        if (embed) {
+          this.addToPbxEmbedFrameworksBuildPhase(file); // PBXCopyFilesBuildPhase
+        }
     }
 
     return file;
@@ -286,10 +297,11 @@
     var file = new pbxFile(fpath, opt);
     file.target = opt ? opt.target : undefined;
 
-    this.removeFromPbxBuildFileSection(file);        // PBXBuildFile
-    this.removeFromPbxFileReferenceSection(file);    // PBXFileReference
-    this.removeFromFrameworksPbxGroup(file);         // PBXGroup
-    this.removeFromPbxFrameworksBuildPhase(file);    // PBXFrameworksBuildPhase
+    this.removeFromPbxBuildFileSection(file);          // PBXBuildFile
+    this.removeFromPbxFileReferenceSection(file);      // PBXFileReference
+    this.removeFromFrameworksPbxGroup(file);           // PBXGroup
+    this.removeFromPbxFrameworksBuildPhase(file);      // PBXFrameworksBuildPhase
+    this.removeFromPbxEmbedFrameworksBuildPhase(file); // PBXCopyFilesBuildPhase
 
     if (opt && opt.customFramework) {
         this.removeFromFrameworkSearchPaths(path.dirname(fpath));
@@ -578,6 +590,24 @@
     }
 }
 
+pbxProject.prototype.addToPbxEmbedFrameworksBuildPhase = function (file) {
+    var sources = this.pbxEmbedFrameworksBuildPhaseObj(file.target);
+    if (sources) {
+        sources.files.push(pbxBuildPhaseObj(file));
+    }
+}
+
+pbxProject.prototype.removeFromPbxEmbedFrameworksBuildPhase = function (file) {
+    var sources = this.pbxEmbedFrameworksBuildPhaseObj(file.target);
+    if (sources) {
+        for (i in sources.files) {
+            if (sources.files[i].comment == longComment(file)) {
+                sources.files.splice(i, 1);
+                break;
+            }
+        }
+    }
+}
 
 pbxProject.prototype.addToProductsPbxGroup = function(file) {
     var productsGroup = this.pbxGroupByName('Products');
@@ -905,6 +935,10 @@
     return this.buildPhaseObject('PBXFrameworksBuildPhase', 'Frameworks', target);
 }
 
+pbxProject.prototype.pbxEmbedFrameworksBuildPhaseObj = function (target) {
+    return this.buildPhaseObject('PBXCopyFilesBuildPhase', 'Embed Frameworks', target);
+};
+
 // Find Build Phase from group/target
 pbxProject.prototype.buildPhase = function(group, target) {
 
@@ -1166,14 +1200,14 @@
     var configurations = nonComments(this.pbxXCBuildConfigurationSection()),
         OTHER_LDFLAGS = 'OTHER_LDFLAGS',
         config, buildSettings;
-    
+
     for (config in configurations) {
         buildSettings = configurations[config].buildSettings;
-        
+
         if (unquote(buildSettings['PRODUCT_NAME']) != this.productName) {
             continue;
         }
-        
+
         if (buildSettings[OTHER_LDFLAGS]) {
             var matches = buildSettings[OTHER_LDFLAGS].filter(function (p) {
                 return p.indexOf(flag) > -1;
@@ -1192,7 +1226,7 @@
 
     for (config in configurations) {
         buildSettings = configurations[config].buildSettings;
-        
+
         buildSettings[buildSetting] = value;
     }
 }
@@ -1203,7 +1237,7 @@
 
     for (config in configurations) {
         buildSettings = configurations[config].buildSettings;
-        
+
         if (buildSettings[buildSetting]) {
             delete buildSettings[buildSetting];
         }
@@ -1245,22 +1279,22 @@
         targetType = type,
         targetSubfolder = subfolder || name,
         targetName = name.trim();
-        
+
     // Check type against list of allowed target types
     if (!targetName) {
         throw new Error("Target name missing.");
-    }    
+    }
 
     // Check type against list of allowed target types
     if (!targetType) {
         throw new Error("Target type missing.");
-    } 
+    }
 
     // Check type against list of allowed target types
     if (!producttypeForTargettype(targetType)) {
         throw new Error("Target type invalid: " + targetType);
     }
-    
+
     // Build Configuration: Create
     var buildConfigurationsList = [
         {